@@ -48,6 +48,20 @@ def gen_Ts(Ti,Tf,nTs):
     Ts = np.r_[Ts, [298.15]]
     Ts.sort()
     return Ts
+def gen_Ps(Ti,Tf,nTs):
+    """
+    Function to generate a range of temperatures.
+
+    :param float Ti: Initial temperature. (Try not to use the value 0. Use 0.1 instead.)
+    :param float Tf: Final temperature.
+    :param int nTs: Number of values. This does not include room temperature, which is included anyways.
+
+    :retun list_of_floats: Values of temperatures between Ti and Tf, inclusive, plus room temperature.
+    """
+    minF_step = (Tf - Ti)/(nTs - 1.)
+    Ts = np.arange(Ti, Tf+1, minF_step)
+    Ts.sort()
+    return Ts
 
 def load_doscar(filename_sufix):
     E = []
@@ -138,13 +152,12 @@ def load_cell(filename_contcar):
     re.findall('[A-Z][^A-Z]*', 'ABC')
     ats_types = re.findall('[A-Z][^A-Z]*', poscar_lines[ix_nats-1].replace('  ','').replace(' ','').replace('\n',''))
     ats_types = [ai+'x' for ai in ats_types]
-
     nats = np.fromstring(poscar_lines[ix_nats], dtype=int,sep=' ')
 
     formula_lst=[]
     for at_i, na_i in zip(ats_types,nats):
         formula_lst.append(at_i*na_i)
-    formula='x'.join(formula_lst)
+    formula=''.join(formula_lst)
     tots_nats=sum(nats)
 
     basis = np.array([np.fromstring(line_i, dtype=float,sep=' ') for line_i in poscar_lines[8:8+tots_nats]])
